/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.fs.s3a.auth;

import java.util.concurrent.atomic.AtomicLong;

import org.apache.hadoop.util.Progressable;

import static org.junit.Assert.assertEquals;

/**
 * A progress callback for testing.
 */
public class ProgressCounter implements Progressable {

  private final AtomicLong count = new AtomicLong();

  public void progress() {
    count.incrementAndGet();
  }

  public long getCount() {
    return count.get();
  }

  public void assertCount(String message, int expected) {
    assertEquals(message, expected, getCount());
  }
}
